==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/CircleTPR/ts/CircleTPR_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ArcTPR</name>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">选择解决方案</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">没有解决方案</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="obsolete">第一条线、弧线或圆</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="obsolete">第二条线、弧线或圆</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="obsolete">圆弧线上的点</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">选择解决方案</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">没有解决方案</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="obsolete">点、两个切线(&amp;g)</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="obsolete">按点向2个实体画圆弧切线</translation>
    </message>
</context>
<context>
    <name>CircleTPR</name>
    <message>
        <location filename="../CircleTPR.js" line="+39"/>
        <source>Point on circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CircleTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle tangential to entity, through point with radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../CircleTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/CircleTPR/ts/CircleTPR_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ArcTPR</name>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">选择解决方案</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">没有解决方案</translation>
    </message>
</context>
<context>
    <name>Circle2TP</name>
    <message>
        <source>First line, arc or circle</source>
        <translation type="obsolete">第一条线、弧线或圆</translation>
    </message>
    <message>
        <source>Second line, arc or circle</source>
        <translation type="obsolete">第二条线、弧线或圆</translation>
    </message>
    <message>
        <source>Point on circle line</source>
        <translation type="obsolete">圆弧线上的点</translation>
    </message>
    <message>
        <source>Choose solution</source>
        <translation type="obsolete">选择解决方案</translation>
    </message>
    <message>
        <source>No solution</source>
        <translation type="obsolete">没有解决方案</translation>
    </message>
    <message>
        <source>Point, 2 Tan&amp;gents</source>
        <translation type="obsolete">点、两个切线(&amp;g)</translation>
    </message>
    <message>
        <source>Draw circle tangential to two entities, through point</source>
        <translation type="obsolete">按点向2个实体画圆弧切线</translation>
    </message>
</context>
<context>
    <name>CircleTPR</name>
    <message>
        <location filename="../CircleTPR.js" line="+39"/>
        <source>Point on circle</source>
        <translation>圆上的点</translation>
    </message>
    <message>
        <location filename="../CircleTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>相切，点和半径(&amp;T)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle tangential to entity, through point with radius</source>
        <translation>过点和给定半径画实体的相切圆</translation>
    </message>
    <message>
        <location filename="../CircleTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>半径：</translation>
    </message>
</context>
</TS>
